Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/windirstat/ntfs.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'src/attribute.rs')
-rw-r--r--src/attribute.rs3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/attribute.rs b/src/attribute.rs
index 5aa3dd9..55cd8e6 100644
--- a/src/attribute.rs
+++ b/src/attribute.rs
@@ -19,6 +19,7 @@ use core::mem;
use core::ops::Range;
use enumn::N;
use memoffset::offset_of;
+use strum_macros::Display;
/// On-disk structure of the generic header of an NTFS attribute.
#[repr(C, packed)]
@@ -93,7 +94,7 @@ struct NtfsNonResidentAttributeHeader {
initialized_size: u64,
}
#[derive(Clone, Copy, Debug, Eq, N, PartialEq)]
#[repr(u32)]
pub enum NtfsAttributeType {
StandardInformation = 0x10,
@@ -93,7 +94,7 @@ struct NtfsNonResidentAttributeHeader {
initialized_size: u64,
}
-#[derive(Clone, Copy, Debug, Eq, N, PartialEq)]
+#[derive(Clone, Copy, Debug, Display, Eq, N, PartialEq)]
#[repr(u32)]
pub enum NtfsAttributeType {